﻿<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet id="stylesheet" version="2.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:template match="/">
		<html>
			<head>
				<title>TV Show Spotlight: <xsl:value-of select="Spotlight/TVShow/Name"/></title>
				<style>
					<!--Scrollbar size-->
					::-webkit-scrollbar {
						width: 5px;
						height: 10px;
					}

					<!--Scrollbar track-->
					::-webkit-scrollbar-track {
					   background: #f1f1f1; 
					}

					<!--Scrollbar handle-->
					::-webkit-scrollbar-thumb {
					   background: #909090;
					}

					<!--Scrollbar handle (hover)-->
					::-webkit-scrollbar-thumb:hover {
						background: #505050;
					}

					<!--Dropdown menu for season selection-->
					.nav-item-dropdown {
						position: relative;
					}

					.nav-item-dropdown:hover .dropdown-menu{
						display: inline-block;
						opacity: 1;
					}
					.nav-item-dropdown:focus-within .dropdown-menu {
						display: inline-block;
						opacity: 1;
					}

					.dropdown-trigger {
						position: relative;
						text-decoration: none;
						color: inherit;
					}


					.dropdown-trigger::after {
						content: "›";
						font-size: 24px;
						font-weight: bold;
					}

					.dropdown-menu {
						background-color: darkgray;
						position: absolute;
						top: 0px;
						left: 125px;
						display: none;
						opacity: 0;
						transition: opacity 0.5s ease;
						width: 160px;
						list-style:none;
						-webkit-padding-start: 0;
						z-index:1;
					}

					.dropdown-menu a {
						color: black;
						text-decoration:none;
					}

					.dropdown-menu-item {
						cursor: pointer;
						padding: 5px;
						text-align: center;
					}
					.dropdown-menu-item:hover {
						background-color: lightgray;
					}

					a:focus {
						outline: 3px solid blue;
					}
          
          a:focus.no-outline {
						outline: none;
          }
				</style>
			</head>
			<body style="background-color: {Spotlight/TVShow/@backColor}; color: {Spotlight/TVShow/@textColor}; font-family: system-ui; font-weight: bold; margin: 10px;">
				<div id="grid_main" role="grid">
					<!--TV Show name and year-->
					<div role="row" aria-rowindex="1" style="font-size: x-large; padding: 20px;">
						<span role="gridcell" aria-colindex="1">
							<a id="link_main" tabindex="0" href="{Spotlight/TVShow/Link}" title="The TV Show Database (TMDB)" style="text-decoration:none; color:inherit">
								<xsl:value-of select="Spotlight/TVShow/Name"/> (<xsl:value-of select="Spotlight/TVShow/NumSeasons"/> Seasons, <xsl:value-of select="Spotlight/TVShow/Years"/>)
							</a>
						</span>
						<xsl:if test="Spotlight/TVShow/PlayURL">
							<span role="gridcell" aria-colindex="2">
								<a href="{Spotlight/TVShow/PlayURL}" title="Play unwatched episodes from library" style="margin-left:5px">
									<img src="https://files.jriver-cdn.com/spotlight/PlayOverlay.png" style="height:20px"/>
								</a>
							</span>
						</xsl:if>
					</div>

					<!--TV Show images: posters and backdrops-->
					<div style="overflow-x: clip;">
						<span style="display: flex;">
							<xsl:for-each select="Spotlight/TVShow/Images/Image">
								<img src="{.}" style="height:200px; object-fit: cover"/>
							</xsl:for-each>
						</span>
					</div>

					<!--Season selection dropdown menu-->
					<div style="padding-left: 20px; padding-top: 20px;" >
						<span role="row" aria-rowindex="2" class="nav-item nav-item-dropdown">
							<span role="gridcell" aria-colindex="1" >
								<a class="dropdown-trigger" href="#">
									Season <xsl:value-of select="Spotlight/TVShow/Season"/>, <xsl:value-of select="Spotlight/TVShow/Episodes/@count"/> Episodes
								</a>
							</span>
							<span role="gridcell" aria-colindex="2" >
								<ul class="dropdown-menu">
									<xsl:call-template name="menu-generator">
										<xsl:with-param name="N" select="Spotlight/TVShow/NumSeasons"/>
										<xsl:with-param name="title" select="Spotlight/TVShow/Name"/>
									</xsl:call-template>
								</ul>
							</span>
						</span>
					</div>

					<!--Episode list (horizontal thumbnails)-->
					<div role="row" aria-rowindex="3" style="font-size: small; display: flex; overflow-x: auto">
						<xsl:for-each select="Spotlight/TVShow/Episodes/Episode">
							<span style="vertical-align:top; text-align:center; margin:10px; display:inline-block; width:227px; font-weight:bold">
								<span role="gridcell" aria-colindex="{position()}" style="position: relative">
									<a href="{./EpLink}" title="TMDB">
										<xsl:choose>
											<xsl:when test="./Image">
												<img src="{./Image}" style="width:227px; height:127px; border-radius:10px" />
											</xsl:when>
											<xsl:otherwise>
												<img src="https://www.themoviedb.org/assets/2/v4/glyphicons/basic/glyphicons-basic-38-picture-grey-c2ebdbb057f2a7614185931650f8cee23fa137b93812ccb132b9df511df1cfac.svg" style="width:222px; height:122px; border-radius:10px; border-color:darkgray; border-style:solid;" />
											</xsl:otherwise>
										</xsl:choose>
									</a>
									<xsl:if test="./PlayURL">
										<a href="{./PlayURL}" title="Play from library" style="position: absolute; top: -5; left:-1">
											<img src="https://files.jriver-cdn.com/spotlight/PlayOverlay.png" style="height:20px"/>
										</a>
									</xsl:if>
								</span>
								<span style="display: block; margin-top: 4px">
									<xsl:value-of disable-output-escaping="yes" select="./Number"/>. <xsl:value-of disable-output-escaping="yes" select="./Title"/>
								</span>
								<span style="display: block; font-size: smaller; font-weight:normal">
									<xsl:value-of select="./AirDate"/>
								</span>
							</span>
						</xsl:for-each>
					</div>

					<!--Cast list (horizontal thumbnails)-->
					<div style="padding-left: 20px; padding-top: 20px;">Cast</div>
					<div role="row" aria-rowindex="4" style="font-size: small; display: flex; overflow-x: auto">
						<xsl:for-each select="Spotlight/TVShow/Cast/Person">
							<span style="vertical-align:top; text-align:center; margin:10px; display:inline-block; width:112px; font-weight:bold">
								<span role="gridcell" aria-colindex="{position()}" style="position: relative">
									<a href="{./PersonLink}" title="Spotlight: {./Name}">
										<xsl:choose>
											<xsl:when test="./Image">
												<img src="{./Image}" style="width:112px; height:142px; border-radius:10px" />
											</xsl:when>
											<xsl:otherwise>
												<img src="https://www.themoviedb.org/assets/2/v4/glyphicons/basic/glyphicons-basic-4-user-grey-d8fe957375e70239d6abdd549fd7568c89281b2179b5f4470e2e12895792dfa5.svg" style="width:107px; height:137px; border-radius:10px; border-color:darkgray; border-style:solid;" />
											</xsl:otherwise>
										</xsl:choose>
									</a>
								</span>
								<span style="display: block; margin-top: 4px">
									<xsl:value-of disable-output-escaping="yes" select="./Name"/>
								</span>
								<span style="display: block; font-size: smaller; font-weight:normal">
									<xsl:value-of select="./Role"/>
								</span>
							</span>
						</xsl:for-each>
					</div>

					<!--Similar TV Shows list (horizontal thumbnails)-->
					<div style="padding-left: 20px; padding-top: 20px;">Recommended TV Shows</div>
					<div role="row" aria-rowindex="5" style="font-size: small; display: flex; overflow-x: auto">
						<xsl:for-each select="Spotlight/TVShow/SimilarSeries/Series">
							<span style="vertical-align:top; text-align:center; margin:10px; display:inline-block; width:112px; font-weight:bold">
								<span role="gridcell" aria-colindex="{position()}" style="position: relative">
									<a href="{./SimilarLink}" title="Spotlight: {./Title}">
										<xsl:choose>
											<xsl:when test="./Poster">
												<img src="{./Poster}" style="width:112px; height:168px; border-radius:10px" />
											</xsl:when>
											<xsl:otherwise>
												<img src="https://www.themoviedb.org/assets/2/v4/glyphicons/basic/glyphicons-basic-38-picture-grey-c2ebdbb057f2a7614185931650f8cee23fa137b93812ccb132b9df511df1cfac.svg" style="width:107px; height:137px; border-radius:10px; border-color:darkgray; border-style:solid;" />
											</xsl:otherwise>
										</xsl:choose>
									</a>

									<xsl:if test="./PlayURL">
										<a href="{./PlayURL}" title="Play from library" style="position: absolute; top: -5; left:-1">
											<img src="https://files.jriver-cdn.com/spotlight/PlayOverlay.png" style="height:20px"/>
										</a>
									</xsl:if>
								</span>
								<span style="display: block; margin-top: 4px">
									<xsl:value-of disable-output-escaping="yes" select="./Title"/>
									<xsl:if test="./Year">
										<span style="display: block; font-size: smaller; font-weight:normal">
											<xsl:value-of select="./Year"/>
										</span>
									</xsl:if>
								</span>
							</span>
						</xsl:for-each>
					</div>

					<!--Overview-->
					<div style="margin: 20px;">
						<div style="font-size: medium; font-weight: normal">
							<xsl:value-of select="Spotlight/TVShow/Overview"/>
						</div>
					</div>

					<!--TMDB attribution, do not remove-->
					<div style="text-align:center">
						<img src="https://www.themoviedb.org/assets/2/v4/logos/v2/blue_square_1-5bdc75aaebeb75dc7ae79426ddd9be3b2be1e342510f8202baf6bffa71d7f5c4.svg" style="height:30" />
					</div>

					<!--Date updated-->
					<div role="row" aria-rowindex="6">
						<div role="gridcell" aria-colindex="1" style="text-align:center; font-size:x-small; font-weight:normal; margin-top:5px;">Updated <xsl:value-of select="Spotlight/TVShow/@dateGenerated"/>  |  <a href="{Spotlight/TVShow/UpdateLink}" title="Update data" style="font-size:x-small; font-weight:normal; color:inherit">Update</a></div>
					</div>				
				</div>
			
				<!--For remote/keyboard navigation-->
				<script src="https://files.jriver-cdn.com/spotlight/spotlight_nav_kb.js"/>
			</body>
		</html>
	</xsl:template>

	<xsl:template name="menu-generator">
		<xsl:param name="N"/>
		<xsl:param name="i" select="1"/>
		<xsl:if test="$N >= $i">
			<!-- menu item -->
			<li class="dropdown-menu-item">
				<a href="{Spotlight/TVShow/SeasonLink}&amp;TVSeason={$i}">Season <xsl:value-of select="$i"/></a>
			</li>
			<!-- recursive call -->
			<xsl:call-template name="menu-generator">
				<xsl:with-param name="N" select="$N"/>
				<xsl:with-param name="i" select="$i + 1"/>
			</xsl:call-template>
		</xsl:if>
	</xsl:template>
</xsl:stylesheet>
