//--------------------------------------------------------------------------------------------------------------
// JavaScript Functions/Routines for all MC and MCC Ultra TrackInfo Plugins for JRiver Media Center V32 & higher
// -------------------------------------------------------------------------------------------------------------
// Copyright (C) 2024 JRiver & EnglishTiger All Rights Reserved.
// Author:    EnglishTiger + Mary Jane
// Email:  		EnglishTiger@outlook.com
// File Name: mc_javascript.js
// Version: 	3.0.0
// -------------------------------------------------------------------------------------------
//
// N.B. Individual Functions/Routines a Specific HTML Page triggers/runs/uses is done VIA an Onload Instruction in the <body> statement of that HTML Page.
//
// matchSkin uses the List Back and Text Colours from the Current Skin  to Customise the TrackInfo Plugin
// The 1st 2 sections load the Hex Values for the Skin's Back and Text Colours
// The 3rd section builds the CSS code/instructions used to carry out the customisation:-
// s1 customises the body section of mc_ultra_layout.css or mcc_ultra_layout.css
// s2 customises the DropDown Menu Entries in normal mode where the back and text colours are those from the skin
// s3 customises the DropDown Menu Entries when the user hovers over them by swapping the back and text colours
// s4 & s5 customise the Horizontal Scrollbar Tracks and Thumbs
// s6 & s7 customise the Vertical Scrollbar Tracks and Thumbs
//
// The final section creates the style section in the head section of the current html file by merging s1, s2, s3, s4, s5, s6. s7 into a single instruction and then writes it to the html file
//
	function matchSkin() {
		var b1 = document.getElementById("backcol").innerText;
		var t1 = document.getElementById("textcol").innerText;

		var s1 = "body {background: #" + b1 + "; color: #" + t1 + ";}";
		var s2 = ".c1-menu1-entry a, .c1-menu2-entry a {background: #" + b1 + "; color: #" + t1 + ";}";
		var s3 = ".c1-menu1-entry a:hover, .c1-menu2-entry a:hover {background: #" + t1 + "; color: #" + b1 + ";}";
		var s4 = "::-webkit-scrollbar-track-piece:horizontal {background: #" + b1 + "; -webkit-box-shadow: inset 0 0 6px #" + t1 + ";}";
		var s5 = "::-webkit-scrollbar-thumb:horizontal {background: #" + t1 + "; -webkit-box-shadow: inset 0 0 6px #" + b1 + ";}";
		var s6 = "::-webkit-scrollbar-track-piece:vertical {background: #" + t1 + "; -webkit-box-shadow: inset 0 0 6px #" + b1 + ";}";
		var s7 = "::-webkit-scrollbar-thumb:vertical {background: #" + b1 + "; -webkit-box-shadow: inset 0 0 6px #" + t1 + ";}";

    var style = document.createElement("style");
    style.innerText = s1 + s2 + s3 + s4 + s5 + s6 + s7;
    document.head.appendChild(style);
	}
// -------------------------------------------------------------------------------------------
// MC semi-colon delimited lists are not very readable as there is no space between the ; and the next element/item
// listEdit uses global replace to add a space between the ; and the next element/item
//
// N.B. Unlike most of the other Functions this one Edits every MC Field/Tag on the page that has it's MC Data Type set to List (semicolon delimited)
// Since TrackInfo Plugins can not access a Field/Tags Data Type everywhere a SemiColon Delimited List, or any field/tag that is being used as a SemiColon Delimited List, is to be displayed the instructions used to display it must include a name="editlist" statement
//
	function listEdit() {
		var x = document.getElementsByName("editlist");
		var i;
		for (i = 0; i < x.length; i++) {
			var str = x[i].textContent;
			if (str == "") { //Empty/Unused Tag/Field
				continue;
			}
			else if (str.indexOf(";") == -1) { // List only contains 1 entry/element (no ; in the data)
				continue;
			}
		else {
			x[i].textContent = str.replace(/;/g, "; "); // List contains multiple entries so add a space behind each ;
			}
		}
	}
// -------------------------------------------------------------------------------------------
// MC Channel No.s are just numbers that indicate the total number of channels
// chExpand extends the info displayed by adding relevant channel layout info
// i.e 3 = 2.1, 6 = 5.1, 8 = 7.1
//
	function chExpand() {
		var c = document.getElementById("expand").textContent;
		var res = null;
		switch (c) {
			case "1":
				res = c + " (Mono)";
				break;
			case "2":
				res = c + " (Stereo)";
				break;
			case "3":
				res = c + " (2.1)";
				break;
			case "4":
				res = c + " (Quadrophonic)";
				break;
			case "5":
				res = c + " (Surround)";
				break;
			case "6":
				res = c + " (5.1 Surround)";
				break;
			case "7":
				res = c + " (Surround)";
				break;
			case "8":
				res = c +  " (7.1 Theatre Surround)";
				break
			case "10":
				res = c +  " (5.1.4 Surround)";
				break
			case "12":
				res = c +  " (7.1.4 Theatre Surround)";
				break
			default:
				res = c;
		}
		document.getElementById("expand").textContent = res;
	}
// -------------------------------------------------------------------------------------------
// Function used to switch between Western Classical and Non-Classical Basic Track Info Display Mode
// It does this by looking for the presence, or absence, of the Name of a Western Classical Music Type/Era in the Hidden Genre Tag
// Where Medieval, Renaissance, Baroque, Classical, Romantic, Modernist, Postmodernist, Contemporary indicates a Western Classical Music Track and any other value indicates a Non-Classical Track
// to reveal (display) the relevant parts of the sections of the html file
//
	function switchBti() {
		var c = document.getElementById("classic").textContent;
		switch (c) {
			case "Medieval":
			case "Renaissance":
			case "Baroque":
			case "Classical":
			case "Romantic":
			case "Modernist":
			case "Postmodernist":
			case "Contemporary":
				document.getElementById("class1").style.display = "block";
				break;
			default:
				document.getElementById("pop1").style.display = "block";
		}
	}
// ---------------------------------------------------------------------------------------------------
// Function used to switch between Western Classical and Non-Classical Display Mode on the Track + Album Info Page
// It does this by looking for the presence, or absence, of the Name of a Western Classical Music Type/Era in the Hidden Genre Tag
// Where Medieval, Renaissance, Baroque, Classical, Romantic, Modernist, Postmodernist, Contemporary indicates a Western Classical Music Track and any other value indicates a Non-Classical Track
// to reveal (display) the relevant parts of the sections of the html file
//
	function switchTai() {
		var c = document.getElementById("classic").textContent;
		switch (c) {
			case "Medieval":
			case "Renaissance":
			case "Baroque":
			case "Classical":
			case "Romantic":
			case "Modernist":
			case "Postmodernist":
			case "Contemporary":
				document.getElementById("c2tac").style.display = "block";
				break;
			default:
				document.getElementById("c2tap").style.display = "block";
		}
	}
// -----------------------------------------------------------------------------------------------------------------------
// Function used to switch between the 3 Lyrics Display Layouts by checking if the Lyrics Field/Tag will cause an overflow
// It will Display the lyrics in 1 Column if the lyrics field is empty or would not cause an overflow
// If the lyrics content causes an overflow in 1 Column they are displayed in 2 Columns
// If the lyrics content causes an overflow in 2 Columns they are displayed in 3 Columns
// If the lyrics causes an overflow in 3 Columns they are displayed in as many columns needed to display them and the Horizontal Scrollbar will also be present
// N.B. For lyrics in 1 Column the Overflow happens Verticaly but for 2 Columns, or more, it happens Horizontaly
// The Divisions Height(d)/Width(f) is the amount of space available to display those lyrics
// The Content Height(e)/Width(g) is the amount of space required to display the lyrics
// NOTE - It is the Browser Engine and NOT this Function that switches from balancing the columns content to filling each column when more than 3 columns are needed to display the lyrics!
	function switchLyr() {
		var c = document.getElementById("lyr1").textContent;  // Gets the Content of the Lyrics Field/Tag
		var d = document.getElementById("lyr1").clientHeight; // Gets the Divisions Available Height
		var e = document.getElementById("lyr1").scrollHeight; // Gets the Content Height if the lyrics will cause an overflow this will be greater than the Division Height		
		if (c == "") { //The field is empty so display a suitable message vertically centered in the division
			document.getElementById("lyr1").textContent = "This Track Does Not Have Any Lyrics !!!";
		}	else if (e > d) { // the lyrics do cause an overflow if 1 column is used so display them in 2 Columns
			document.getElementById("lyr1").style.display = "none";
			document.getElementById("lyr2").style.display = "block";	
			var f = document.getElementById("lyr2").clientWidth; // Gets the Divisions Available Width
			var g = document.getElementById("lyr2").scrollWidth; // Gets the Content Width if the lyrics will cause an overlow this will be greater than the Division Width		
			if (g > f) { document.getElementById("lyr2").style.columnCount = "3"; } // the lyrics do cause an overflow so display them in 3 or More Columns
		}
	}
// -------------------------------------------------------------------------------------------------------------------------------------------------------------------
// Function called when the lyrics page display panel is resized
// N.B. Unlike the other Functions which are triggered by an OnLoad instuction this one is triggered by an onresize="redrawLyr()"; instuction in the <body> statement of HTML Pages that Display Lyrics
// Note - If this function did not exist the only way to get switchLyr() to use the dimensions of the resized display panel would be by relaoding the relevant HTML page
// This function resets any settings that switchLyr() can modify back to their initial values then runs switchLyr() which will use the new display panel size when deciding how to display the lyrics
	function redrawLyr() {
		// reset all the settings that switchLyr() can modify back to their initial values
		document.getElementById("lyr1").style.display = "block";
		document.getElementById("lyr2").style.display = "none";	
		document.getElementById("lyr2").style.columnCount = "2";
		// run switchLyr()
		switchLyr();
	}
// ---------------------------------------------------------------------------------------------------
